==> HiClimR_2.1.7.tar.gz: HiClimR/R/coarseR.R <==
# $Id: coarseR.R, v2.1.7 2020/11/05 12:00:00 hsbadr EPS JHU               #
#-------------------------------------------------------------------------#
# This function is a part of HiClimR R package.                           #
#-------------------------------------------------------------------------#
#  HISTORY:                                                               #
#-------------------------------------------------------------------------#
#  Version  |  Date      |  Comment   |  Author          |  Email         #
#-------------------------------------------------------------------------#
#           |  May 1992  |  Original  |  F. Murtagh      |                #
#           |  Dec 1996  |  Modified  |  Ross Ihaka      |                #
#           |  Apr 1998  |  Modified  |  F. Leisch       |                #
#           |  Jun 2000  |  Modified  |  F. Leisch       |                #
#-------------------------------------------------------------------------#
#   1.0.0   |  03/07/14  |  HiClimR   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.0.1   |  03/08/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.0.2   |  03/09/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.0.3   |  03/12/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.0.4   |  03/14/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.0.5   |  03/18/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.0.6   |  03/25/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#-------------------------------------------------------------------------#
#   1.0.7   |  03/30/14  |  Hybrid    |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.0.8   |  05/06/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#-------------------------------------------------------------------------#
#   1.0.9   |  05/07/14  |  CRAN      |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.1.0   |  05/15/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.1.1   |  07/14/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.1.2   |  07/26/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.1.3   |  08/28/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.1.4   |  09/01/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.1.5   |  11/12/14  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#-------------------------------------------------------------------------#
#   1.1.6   |  03/01/15  |  GitHub    |  Hamada S. Badr  |  badr@jhu.edu  #
#-------------------------------------------------------------------------#
#   1.2.0   |  03/27/15  |  MVC       |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.2.1   |  05/24/15  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.2.2   |  07/21/15  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   1.2.3   |  08/05/15  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#-------------------------------------------------------------------------#
#   2.0.0   |  12/22/18  |  NOTE      |  Hamada S. Badr  |  badr@jhu.edu  #
#   2.1.0   |  01/01/19  |  NetCDF    |  Hamada S. Badr  |  badr@jhu.edu  #
#   2.1.1   |  01/02/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   2.1.2   |  01/04/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   2.1.3   |  01/10/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   2.1.4   |  01/20/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   2.1.5   |  12/10/19  |  inherits  |  Hamada S. Badr  |  badr@jhu.edu  #
#   2.1.6   |  02/22/20  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#   2.1.7   |  11/05/20  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
#-------------------------------------------------------------------------#
# COPYRIGHT(C) 2013-2020 Earth and Planetary Sciences (EPS), JHU.         #
#-------------------------------------------------------------------------#
# Function: Coarsening spatial resolution for gridded data                #
#-------------------------------------------------------------------------#

coarseR <-
  function(x = x,
           lon = lon,
           lat = lat,
           lonStep = 1,
           latStep = 1,
           verbose = TRUE) {
    xc <- list()
    xc$lon <- lon
    xc$lat <- lat
    xc$x <- x
    
    if (!is.null(lon) && !is.null(lat)) {
      if (as.numeric(dim(x)[1]) == as.numeric(length(unique(lon)) * length(unique(lat)))) {
        lon0 <- unique(lon)
        lat0 <- unique(lat)
        xGrid <- grid2D(lon0, lat0)
        
        rownames(x) <-
          paste(c(xGrid$lon), c(xGrid$lat), sep = ",")
        
        lon1 <- lon0[seq(1, length(lon0), by = lonStep)]
        lat1 <- lat0[seq(1, length(lat0), by = latStep)]
        
        xc$lon <- c(grid2D(lon1, lat1)$lon)
        xc$lat <- c(grid2D(lon1, lat1)$lat)
        
        if (lonStep > 1 || latStep > 1) {
          xc$x <- x[which(rownames(x) %in% paste(xc$lon, xc$lat,
                                                 sep = ",")),]
          
          # Return the original row numbers
          rownumbers <- 1:nrow(x)
          xc$rownum <-
            rownumbers[which(rownames(x) %in% paste(xc$lon, xc$lat,
                                                    sep = ","))]
        }
      } else {
        if (lonStep > 1 || latStep > 1) {
          if (verbose)
            write("---> WARNING: ungridded data is not supported for coarsening!",
                  "")
        }
      }
    } else {
      if (verbose)
        write("---> WARNING: valid longitude and latitude vectors are not provided!",
              "")
    }
    
    #gc()
    return(xc)
  }

==> HiClimR_2.2.1.tar.gz: HiClimR/R/coarseR.R <==
# $Id: coarseR.R                                                          #
#-------------------------------------------------------------------------#
# This function is a part of HiClimR R package.                           #
#-------------------------------------------------------------------------#
# COPYRIGHT(C) 2013-2021 Earth and Planetary Sciences (EPS), JHU.         #
#-------------------------------------------------------------------------#
# Function: Coarsening spatial resolution for gridded data                #
#-------------------------------------------------------------------------#

coarseR <-
  function(x = x,
           lon = lon,
           lat = lat,
           lonStep = 1,
           latStep = 1,
           verbose = TRUE) {
    xc <- list()
    xc$lon <- lon
    xc$lat <- lat
    xc$x <- x

    if (!is.null(lon) && !is.null(lat)) {
      nlon_unique <- length(unique(lon))
      nlat_unique <- length(unique(lat))
      if (as.numeric(dim(x)[1]) == as.numeric(nlon_unique * nlat_unique)) {
        lon0 <- unique(lon)
        lat0 <- unique(lat)
        xGrid <- grid2D(lon0, lat0)

        rownames(x) <-
          paste(c(xGrid$lon), c(xGrid$lat), sep = ",")

        lon1 <- lon0[seq(1, length(lon0), by = lonStep)]
        lat1 <- lat0[seq(1, length(lat0), by = latStep)]

        xc$lon <- c(grid2D(lon1, lat1)$lon)
        xc$lat <- c(grid2D(lon1, lat1)$lat)

        if (lonStep > 1 || latStep > 1) {
          xc$x <- x[which(rownames(x) %in% paste(xc$lon, xc$lat,
            sep = ","
          )), ]

          # Return the original row numbers
          rownumbers <- seq_len(nrow(x))
          xc$rownum <-
            rownumbers[which(rownames(x) %in% paste(xc$lon, xc$lat,
              sep = ","
            ))]
        }
      } else {
        if (lonStep > 1 || latStep > 1) {
          if (verbose) {
            write(
              "---> WARNING: ungridded data is not supported for coarsening!",
              ""
            )
          }
        }
      }
    } else {
      if (verbose) {
        write(
          paste(
            "---> WARNING:",
            "valid longitude and latitude vectors are not provided!"
          ),
          ""
        )
      }
    }

    return(xc)
  }
